@@ -21,11 +21,6 @@ def dcopy(N, DX, INCX, DY, INCY):
     -------
     None
 
-    Raises
-    ------
-    Exception
-        If N <= 0
-
     See Also
     --------
     scopy : Single-precision real copy
@@ -34,6 +29,7 @@ def dcopy(N, DX, INCX, DY, INCY):
 
     Notes
     -----
+    Online PyBLAS documentation: https://nbviewer.jupyter.org/github/timleslie/pyblas/blob/main/docs/dcopy.ipynb
     Reference BLAS documentation: https://github.com/Reference-LAPACK/lapack/blob/v3.9.0/BLAS/SRC/dcopy.f
 
     Examples
